@@ -181,7 +181,7 @@ class SettMisc(object):
         vPackage = list(response['releases'].keys())
         vPackage.sort(key=StrictVersion, reverse=True)
 
-        verBeta = [x for x in vPackage if 'b' in x]
+        verBeta = [x for x in vPackage if 'a' in x]
         verRelease = [x for x in vPackage if 'b' not in x and 'a' not in x]
 
         self.log.debug(f'Package Beta:   {verBeta[:10]}')
